# TU TISS plugin for LDAP User Managment Tools

[ "$0" != "${BASH_SOURCE[0]}" ] || {
    echo "$0: this script must be sourced, not called" >&2
    exit 1
}

# plugin_interactive_resolve <ret-aa-vn> <key> <csv-index> <attribute> [..]
# where csv-index is the order of attributes, e.g. "first_name;last_name"
# errors: 91 (not all attributes found)
function plugin_csv_resolve() {
    (( $# > 2 )) || bb_fatal "plugin_interactive_resolve called with $#" \
	"instead of 3 or more args"

    local _ret_aa_vn="$1"
    local _key="$2"
    local _index_string="$3"
    shift 3

    local -n _ret_aa_ref="$_ret_aa_vn"

    local _attr _value

    # clear destination dict
    _ret_aa_ref=()

    # read CSV index to array
    local -a _index_array
    IFS=\; read -r -a _index_array <<< "$_index_string"

    # convert index for easy lookup
    local -A _index
    local -i _i=0
    for _attr in "${_index_array[@]}"
    do
	_index[$_attr]="$_i"
	_i=$((_i + 1))
    done

    # read key to array
    local -a _key_array
    IFS=\; read -r -a _key_array <<< "$_key"

    local _retval=0

    # read values from key
    for _attr in "$@"
    do
	# get index of value
	_i="${_index[$_attr]}"

	# get value
	_value="${_key_array[$_i]-}"
	if [ -z "$_value" ]
	then
	    bb_msg warning "plugin_csv_resolve: cound not find" \
		"requested attribute: $_attr"
	    _retval=91
	else
	    _ret_aa_ref["$_attr"]="$_value"
	fi
    done

    return "$_retval"
}
